<?php
	/*-------------------------------------------------------------------------
	 * L24_EXPORT.CSV
	 * 
	 * Availability export routing for Master Liveaboards. 
	 */	

	//  Pull in the configuration files.
	//
	require_once( "config.inc.php");
	
	//  Pull in support libraries and classes.
	//
	require_once( "class.db_class.inc.php");
	
	$vessel_codes = array(
				"Galapagos Master"=>1416
				);
	
	$csv_file = tempnam(sys_get_temp_dir(), 'L24_ML_');

	//  Construct the SQL connection URI.
	//
	$sql_uri = "{$db_driver}:dbname={$db_name};host={$db_host};charset=utf8";
	
	//  Try opening the database.
	//
	try {
    	$db = new dbClass($sql_uri, $db_user, $db_password );
    	$db->setAttribute( PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION );
	} 
	catch (PDOException $e) {

		die( "ERROR: Unable to connect to database.");
	}
	
	//  Set the name of the database containing the schedules. 
	//
	$db->schedule_db = $cfg_schedule_db;
		
	$a_trips = $db->getVesselTrips( );
	
	$f = fopen( $csv_file, "w");
	
	//  For each trip found, output the required fields.
	//
	foreach( $a_trips as $trip ) {
		
		//  Tweak San Cristobal dis(embarkation) as requested by Martina @ Schoener Tauchen
		//
		$trip->trip_embarkation_point = str_replace( "San Cristobal Airport", "San Cristobal", $trip->trip_embarkation_point );
		$trip->trip_disembarkation_point = str_replace( "San Cristobal Airport", "San Cristobal", $trip->trip_disembarkation_point );
		
		$trip_record =  array(
							$vessel_codes[ $trip->vessel_name ],
							$trip->vessel_name, 
							$trip->trip_start_date, 
							$trip->trip_end_date, 
							$trip->trip_embarkation_point,
							$trip->trip_disembarkation_point,
							$trip->trip_itinerary_long, 
							$trip->trip_availability,
							"X" 
							);
		
		
		fputcsv( $f, $trip_record, "|" );
	}
	
	//  Close the CSV file. 
	//
	fclose( $f );
	
	//  Generate content type headers.
	//
	header("Content-type: application/octet-stream");
	header("Content-Disposition: attachment; filename=\"master_liveaboards_availability.csv\"");
	
	//  Send the contents of the CSV to the output stream.
	//
	readfile( $csv_file );
	
	//  Remove the CSV file from the disk.
	//
	unlink( $csv_file );

	?>